summaryrefslogtreecommitdiffstats
path: root/modules-available/rebootcontrol/inc/rebootqueries.inc.php
diff options
context:
space:
mode:
authorSimon Rettberg2018-04-24 15:54:00 +0200
committerSimon Rettberg2018-04-24 15:54:00 +0200
commitb48e755affc865547ab148340f586ae9a297c8f5 (patch)
treef15da9b1ced06785594467fe84fd63db34900461 /modules-available/rebootcontrol/inc/rebootqueries.inc.php
parent[translation] Satelliten-Server -> Satellitenserver (diff)
downloadslx-admin-b48e755affc865547ab148340f586ae9a297c8f5.tar.gz
slx-admin-b48e755affc865547ab148340f586ae9a297c8f5.tar.xz
slx-admin-b48e755affc865547ab148340f586ae9a297c8f5.zip
[rebootcontrol] Try clients first that are known to be online
This prevents long delays if a large amount of clients is selected where the majority is offline.
Diffstat (limited to 'modules-available/rebootcontrol/inc/rebootqueries.inc.php')
-rw-r--r--modules-available/rebootcontrol/inc/rebootqueries.inc.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/modules-available/rebootcontrol/inc/rebootqueries.inc.php b/modules-available/rebootcontrol/inc/rebootqueries.inc.php
index 3dc3183f..525a9e58 100644
--- a/modules-available/rebootcontrol/inc/rebootqueries.inc.php
+++ b/modules-available/rebootcontrol/inc/rebootqueries.inc.php
@@ -44,13 +44,13 @@ class RebootQueries
/**
* Get machines by list of UUIDs
* @param string[] $list list of system UUIDs
* @return array list of machines with machineuuid, clientip and locationid
*/
public static function getMachinesByUuid($list)
{
if (empty($list))
return array();
- $res = Database::simpleQuery("SELECT machineuuid, clientip, locationid FROM machine
+ $res = Database::simpleQuery("SELECT machineuuid, clientip, state, locationid FROM machine
WHERE machineuuid IN (:list)", compact('list'));
return $res->fetchAll(PDO::FETCH_ASSOC);
}
@@ -44,13 +44,13 @@ class RebootQueries
* Get machines by list of UUIDs
* @param string[] $list list of system UUIDs
- * @return array list of machines with machineuuid, clientip and locationid
+ * @return array list of machines with machineuuid, clientip, state and locationid
*/
public static function getMachinesByUuid($list)